summaryrefslogtreecommitdiff
path: root/sw/inc/crsrsh.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/crsrsh.hxx')
-rw-r--r--sw/inc/crsrsh.hxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/sw/inc/crsrsh.hxx b/sw/inc/crsrsh.hxx
index 31cad2cd6e71..689a354fffc7 100644
--- a/sw/inc/crsrsh.hxx
+++ b/sw/inc/crsrsh.hxx
@@ -332,8 +332,9 @@ public:
void ExtendedSelectAll(bool bFootnotes = true);
/// If ExtendedSelectAll() was called and selection didn't change since then.
bool ExtendedSelectedAll();
- /// If document body starts with a table.
- bool StartsWithTable();
+ enum class StartsWith { None, Table, HiddenPara };
+ /// If document body starts with a table or starts/ends with hidden paragraph.
+ StartsWith StartsWith_();
SwCursor* GetCursor( bool bMakeTableCursor = true ) const;
// return only the current cursor